@@ -49,6 +49,10 @@ static char rcsid[] = "$Id: edquota.c,v 1.6 1995/07/23 09:58:06 mvw Exp mvw $";
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/file.h>
+#define __KERNEL__
+#include <linux/kdev_t.h>
+#include <linux/wait.h>
+#undef __KERNEL__
 #include <linux/quota.h>
 #include <errno.h>
 #include <mntent.h>
@@ -324,7 +328,7 @@ editit(char *tmpfile)
       setgid(getgid());
       setuid(getuid());
       if ((ed = getenv("EDITOR")) == (char *) 0)
-         ed = _PATH_VI;
+         ed = "/bin/ae";
       execlp(ed, ed, tmpfile, 0);
       perror(ed);
       exit(1);
