@@ -49,6 +49,10 @@ static char rcsid[] = "$Id: quota.c,v 1.3 1995/05/15 13:49:14 mvw Exp $";
 #include <sys/param.h>
 #include <sys/file.h>
 #include <sys/stat.h>
+#define __KERNEL__
+#include <linux/kdev_t.h>
+#include <linux/wait.h>
+#undef __KERNEL__
 #include <linux/quota.h>
 #include <stdio.h>
 #include <mntent.h>
@@ -517,7 +521,7 @@ struct quotause *getprivs(long id, int quotatype)
 
       if (strcmp(mnt->mnt_type, MNTTYPE_NFS)) {
          if (quotactl(qcmd, mnt->mnt_fsname, id, (caddr_t)&qup->dqblk) != 0) {
-            if (errno == ENOSYS)
+            if (errno == ENOSYS || errno == ESRCH)
                continue;
             if ((fd = open(qfpathname, O_RDONLY)) < 0) {
                perror(qfpathname);
