@@ -48,6 +48,10 @@ static char rcsid[] = "$Id: quotaon.c,v 1.3 1995/05/15 13:49:14 mvw Exp $";
 #include <sys/param.h>
 #include <sys/file.h>
 #include <sys/mount.h>
+#define __KERNEL__
+#include <linux/kdev_t.h>
+#include <linux/wait.h>
+#undef __KERNEL__
 #include <linux/quota.h>
 #include <stdio.h>
 #include <string.h>
