@@ -47,6 +47,10 @@ static char rcsid[] = "$Id: repquota.c,v 1.4 1995/07/23 09:58:06 mvw Exp mvw $";
  */
 #include <sys/param.h>
 #include <sys/stat.h>
+#define __KERNEL__
+#include <linux/kdev_t.h>
+#include <linux/wait.h>
+#undef __KERNEL__
 #include <linux/quota.h>
 #include <mntent.h>
 #include <pwd.h>
@@ -284,7 +288,8 @@ struct fileusage *addid(u_long id, int type, char *name)
    if (id > highid[type])
       highid[type] = id;
    if (name) {
-      memcpy(fup->fu_name, name, 10);
+      strncpy(fup->fu_name, name, 10);
+      fup->fu_name[10] = '\0';
    } else {
       sprintf(fup->fu_name, "%u", id);
    }
